@@ -4,8 +4,9 @@ use strict;
 use utf8;
 use Modern::Perl;
 
-our $VERSION = '0.013';    # VERSION
+our $VERSION = '0.014';    # VERSION
 use DBI ':sql_types';
+use English '-no_match_vars';
 use Moo;
 use Sub::Quote;
 use namespace::autoclean -also => qr{\A _}xms;
@@ -27,8 +28,8 @@ sub violates {
     my @text_types = (
         qw(TEXT NTEXT CLOB NCLOB CHARACTER CHAR NCHAR VARCHAR VARCHAR2 NVARCHAR2),
         'CHARACTER VARYING',
-        map     { uc $_->{TYPE_NAME} }
-            map { $source->storage->dbh->type_info($_) } (
+        map     { uc $ARG->{TYPE_NAME} }
+            map { $source->storage->dbh->type_info($ARG) } (
             SQL_CHAR,        SQL_CLOB,
             SQL_VARCHAR,     SQL_WVARCHAR,
             SQL_LONGVARCHAR, SQL_WLONGVARCHAR,
@@ -36,9 +37,9 @@ sub violates {
     );
 
     my %column = %{ $source->columns_info };
-    return join "\n", map {"$_ is a nullable text column."} grep {
-        uc( $column{$_}{data_type} // q{} ) ~~ @text_types
-            and $column{$_}{is_nullable}
+    return join "\n", map {"$ARG is a nullable text column."} grep {
+        uc( $column{$ARG}{data_type} // q{} ) ~~ @text_types
+            and $column{$ARG}{is_nullable}
     } keys %column;
 }
 
@@ -62,7 +63,7 @@ DBIx::Class::Schema::Critic::Policy::NullableTextColumn - Check for ResultSource
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 SYNOPSIS
 
